Details of GibbsExcessLiquid Phase Model
========================================

.. contents:: :local:

There are lots of options that get called "ideal". The GibbsExcessLiquid object implements many of them, which means the configuration is complicated and the defaults may not act as expected.